/**
 * Smart Component metadata
 */
{
	"fileName" : "component.js",

	/**
	 * Category name for the component.
	 * This name is use by the user interface and has multilanguage support.
	 * Simply use a ISO 3166 id with a value for the derived language:
	 * <br>"category" :  {
	 * <br>		"de-de" : "german category name",
	 * <br>		"en-us" : "enlish category name"
	 * <br>}
	 * 
	 * Fallback language: en-us
	 */
	"category" : {
		"en-us" : "Getting started example",
		"de-de" : "'Getting started' Beispiel"
	},

	/**
	 * Name for the component.
	 * This name is use by the user interface and has multilanguage support.
	 * Simply use a ISO 3166 id with a value for the derived language:
	 * <br>"name" :  {
	 * <br>		"de-de" : "Bild",
	 * <br>		"en-us" : "Picture"
	 * <br>}
	 * 
	 * Fallback language: en-us
	 */
	"name" :  {
		"en-us" : "Picture",
		"de-de" : "Bild"
	},

	/**
	 * Component version.
	 */
	"version" : {

		/**
		 * Major version
		 */
		"major" : "1",

		/**
		 * Minor version
		 */
		"minor" : "0",

		/**
		 * Revision
		 */
		"revision" : "0"
	},

	/**
	 * Component events.
	 * 
	 * Events that the component can fire.
	 * This events can be selected by the author in the "Add control trigger"-dialog.
	 * Keep in mind, that you have to use the exact same name (case sensitive) to fire such an event in in your
	 * component thru the API function. 
	 */
	"events" : {
		"onShowQuickInfo" : {
           "en-us" : "On show quickinfo",
           "de-de" : "Wenn Quickinfo angezeigt werden soll"
       }
	},
	
	/**
	 * Component parameters. Any parameter outside the "com.tts"-namespace will be passed thru the component context.
	 */
	"parameter" : {

		/**
		 * KnowledgeForce properties.
		 * This parameters are used by the authoring environment and you can not define new parameters in that namespace.
		 *  
		 */
		"com.tts" : {

			/**
			 * Initial x offset of a component instance.   
			 */
			"left" : "100",

			/**
			 * Initial y offset of a component instance.   
			 */
			"top" : "100",
			
			/**
			 * Initial width of a component instance.   
			 */
			"width" : "500",

			/**
			 * Initial height of a component instance.   
			 */
			"height" : "281",
			
			/**
			 * Sets the mode, how an author can resize a component instance.
			 * Possible values are: "full", "width" and "height"   
			 */
			"scaling_mode" : "full",

			/**
			 * Description of the instance of a SmartComponent on a page of
			 * the E-Learning, which is shown in the lists of the authoring
			 * environment TT Knowledge Force.
			 */
			"description" : ""
		},

		
		/**
		 * custom parameters
		 */
		
		 /**
		  * For example, this parameter is used to pass the path to the picture, that will displayed by the component.
		  */ 
		"picture_file" : "",

				
		/**
		 * i18n localized strings
		 *
		 * Text parameters used like this are automatically included in the translation
		 * workflow of the TT Knowledge Force.
		 * Please note that this notation is different from the notation above concerning
		 * the category and the name of the SmartComponent.
		 */
		
		/**
		 * default title of the caption if the document language is German
		 */
		"en-us" : {
			"caption" : "SmartComponent example"
		},

		/**
		 * default title of the caption if the document language is German
		 */
		"de-de" : {
			"caption" : "SmartComponent Beispiel"
		}
	}
}